@@ -1,11 +1,11 @@
 from dataclasses import dataclass
 from typing import Any
 
-from openapi_core.exceptions import OpenAPIError
+from openapi_core.deserializing.exceptions import DeserializeError
 
 
 @dataclass
-class CastError(OpenAPIError):
+class CastError(DeserializeError):
     """Schema cast operation error"""
 
     value: Any
