@@ -2,5 +2,5 @@ from typing import Any
 from typing import Callable
 from typing import Dict
 
-DeserializerCallable = Callable[[Any], Any]
+DeserializerCallable = Callable[[bytes], Any]
 MediaTypeDeserializersDict = Dict[str, DeserializerCallable]
